=================================
Russound RIO Async Python Package
=================================
This is the new home for the Russound Rio Python package, forked from @wickerwaka's excellent work at https://github.com/wickerwaka/russound_rio. 

This module implements a Python client for the Russound I/O (RIO) protocol used to control Russound audio controllers. RIO supports a superset of the RNET feature set, allows for push notifications of system changes and supports TCP/IP and RS232 communication.
